'use strict';

/**
 * Base64 decodes data.
 * @param {object} req - node request
 * @param {function} cb - default callback
 * @param {function} cb.error - callback for 'error' output
 * @param {function} cb.decoded - callback for 'decoded' output
 * @returns {null}
 */
exports = module.exports = function (req, cb) {
	var data = req.params.data;
	if (data === undefined || data === null) {
		return cb('invalid argument');
	}

	try {
		var buf = Buffer.from(data, 'base64');
		if (!req.params.as || req.params.as === 'buffer') {
			return cb.decoded(null, buf);
		}
		if (req.params.as === 'string') {
			var str = buf.toString('utf8');
			return cb.decoded(null, str);
		}
		if (req.params.as === 'number') {
			// number
			var num = parseInt(buf, 10);
			if (num === Number.isNaN()) {
				return cb.error('NaN');
			}
			return cb.decoded(null, num);
		} else if (req.params.as === 'boolean') {
			// boolean
			var _str = buf.toString('utf8').toLowerCase();
			if (_str === 'false' || _str === '0' || _str === '') {
				cb.decoded(null, false);
			} else {
				cb.decoded(null, true);
			}
		} else {
			// object
			return cb.decoded(null, JSON.parse(buf.toString('utf8')));
		}
	} catch (ex) {
		return cb.error(null, ex);
	}
};